Index: /trunk/src/VBox/ValidationKit/testdriver/vboxinstaller.py
===================================================================
--- /trunk/src/VBox/ValidationKit/testdriver/vboxinstaller.py	(revision 66621)
+++ /trunk/src/VBox/ValidationKit/testdriver/vboxinstaller.py	(revision 66622)
@@ -841,5 +841,5 @@
                 asProdCodes.append([sProdCode, sProdName]);
 
         # Before we start uninstalling anything, just ruthlessly kill any
         # msiexec, drvinst and some rundll process we might find hanging around.
         if self._isProcessPresent('rundll32'):
@@ -876,4 +876,14 @@
                 if cKilled > 0:
                     time.sleep(16); # fudge.
+
+        # cdb.exe sometimes stays running (from utils.getProcessInfo), blocking
+        # the scratch directory. No idea why.
+        if self._isProcessPresent('cdb'):
+            cTimes = 0;
+            while cTimes < 3:
+                cKilled = self._killProcessesByName('cdb', 'cdb.exe from getProcessInfo');
+                if cKilled <= 0:
+                    break;
+                time.sleep(2); # fudge.
 
         # Do the uninstalling.
@@ -841,5 +841,5 @@
                 asProdCodes.append([sProdCode, sProdName]);
 
-        # Before we start uninstalling anything, just ruthlessly kill any
+        # Before we start uninstalling anything, just ruthlessly kill any cdb,
         # msiexec, drvinst and some rundll process we might find hanging around.
         if self._isProcessPresent('rundll32'):
